@@ -64,8 +64,12 @@ cifs_open(struct inode *inode, struct file *file)
 		desiredAccess = GENERIC_READ;
 	else if ((file->f_flags & O_ACCMODE) == O_WRONLY)
 		desiredAccess = GENERIC_WRITE;
-	else if ((file->f_flags & O_ACCMODE) == O_RDWR)
-		desiredAccess = GENERIC_ALL;
+	else if ((file->f_flags & O_ACCMODE) == O_RDWR) {
+		/* GENERIC_ALL is too much permission to request */
+		/* can cause unnecessary access denied on create */
+		/* desiredAccess = GENERIC_ALL; */
+		desiredAccess = GENERIC_READ | GENERIC_WRITE;
+	}
 
 /*********************************************************************
  *  open flag mapping table:
@@ -192,11 +196,12 @@ cifs_open(struct inode *inode, struct file *file)
 
 /* Try to reaquire byte range locks that were released when session */
 /* to server was lost */
-int relock_files(struct cifsFileInfo * cifsFile)
+static int cifs_relock_file(struct cifsFileInfo * cifsFile)
 {
 	int rc = 0;
 
-/* list all locks open on this file */
+/* BB list all locks open on this file and relock */
+
 	return rc;
 }
 
@@ -241,7 +246,7 @@ static int cifs_reopen_file(struct inode *inode, struct file *file)
         else if ((file->f_flags & O_ACCMODE) == O_WRONLY)
                 desiredAccess = GENERIC_WRITE;
         else if ((file->f_flags & O_ACCMODE) == O_RDWR)
-                desiredAccess = GENERIC_ALL;
+                desiredAccess = GENERIC_READ | GENERIC_WRITE;
 
         if (oplockEnabled)
                 oplock = REQ_OPLOCK;
@@ -291,6 +296,7 @@ static int cifs_reopen_file(struct inode *inode, struct file *file)
                                 pCifsInode->clientCanCacheRead = FALSE;
                                 pCifsInode->clientCanCacheAll =  FALSE;
                         }
+                        cifs_relock_file(pCifsFile);
                 }
         }
 
@@ -1022,7 +1028,7 @@ cifs_readpages(struct file *file, struct address_space *mapping,
 			break;
 		}
 		if(smb_read_data) {
-			buf_release(smb_read_data);
+			cifs_buf_release(smb_read_data);
 			smb_read_data = 0;
 		}
 		bytes_read = 0;
@@ -1288,6 +1294,11 @@ construct_dentry(struct qstr *qstring, struct file *file,
 		}
 	} else {
 		tmp_dentry = d_alloc(file->f_dentry, qstring);
+		if(tmp_dentry == NULL) {
+			cERROR(1,("Failed allocating dentry"));
+			return;
+		}
+			
 		*ptmp_inode = new_inode(file->f_dentry->d_sb);
 		if(ptmp_inode) {
 			pCifsI = CIFS_I(*ptmp_inode);
@@ -1656,6 +1667,7 @@ cifs_readdir(struct file *file, void *direntry, filldir_t filldir)
 				break;
 			}
 			searchHandle = cifsFile->netfid;
+			cFYI(1,("FindNext resume name: %s len: %d",cifsFile->search_resume_name,cifsFile->resume_name_length));
 			rc = CIFSFindNext(xid, pTcon, pfindData,
 				&findNextParms, searchHandle, 
 				cifsFile->search_resume_name,
